==> zxing_lib-0.2.0.tar.gz: lib/src/binarizer.dart <==
/*
 * Copyright 2009 ZXing authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import 'common/bit_array.dart';
import 'common/bit_matrix.dart';
import 'luminance_source.dart';

/// This class hierarchy provides a set of methods to convert luminance data to 1 bit data.
///
/// It allows the algorithm to vary polymorphically, for example allowing a very expensive
/// thresholding technique for servers and a fast one for mobile. It also permits the implementation
/// to vary, e.g. a JNI version for Android and a Java fallback version for other platforms.
abstract class Binarizer {
  final LuminanceSource _source;

  Binarizer(this._source);

  LuminanceSource get luminanceSource => _source;

  /// Converts the row [y] of luminance data to [row](true means black).
  ///
  /// If [row] is null or too small, it will be ignored.
  /// if the row [y] can't be binarized [NotFoundException] will be thrown
  /// May actually do the conversion, or return cached data.
  /// Callers should assume this method is expensive and call it as seldom as possible.
  /// This method is intended for decoding 1D barcodes and may choose to apply sharpening.
  /// For callers which only examine one row of pixels at a time, the same BitArray should be reused
  /// and passed in with each call for performance. However it is legal to keep more than one row
  /// at a time if needed
  BitArray getBlackRow(int y, BitArray? row);

  /// Get the 2D array of bits for the image (true means black).
  ///
  /// As above, assume this method is expensive and do not call it repeatedly.
  /// This method is intended for decoding 2D barcodes and may or may not apply sharpening.
  /// Therefore, a row from this matrix may not be identical to one
  /// fetched using getBlackRow(), so don't mix and match between them.
  /// throws [NotFoundException] if image can't be binarized to make a matrix
  BitMatrix get blackMatrix;

  /// Creates a new [Binarizer] with the same type as this Binarizer implementation, but with pristine
  /// state.
  ///
  /// The new [Binarizer] will operate on [source].
  /// This is needed because Binarizer implementations may be stateful, e.g. keeping a cache
  /// of 1 bit data. See Effective Java for why we can't use Java's clone() method.
  Binarizer createBinarizer(LuminanceSource source);

  int get width => _source.width;

  int get height => _source.height;
}

==> zxing_lib-1.1.1.tar.gz: lib/src/binarizer.dart <==
/*
 * Copyright 2009 ZXing authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import 'common/bit_array.dart';
import 'common/bit_matrix.dart';
import 'luminance_source.dart';

/// This class hierarchy provides a set of methods to convert luminance data to 1 bit data.
///
/// It allows the algorithm to vary polymorphically, for example allowing a very expensive
/// thresholding technique for servers and a fast one for mobile. It also permits the implementation
/// to vary, e.g. a JNI version for Android and a Java fallback version for other platforms.
abstract class Binarizer {
  final LuminanceSource _source;

  Binarizer(this._source);

  LuminanceSource get luminanceSource => _source;

  /// Converts the row [y] of luminance data to [row](true means black).
  ///
  /// If [row] is null or too small, it will be ignored.
  /// if the row [y] can't be binarized [NotFoundException] will be thrown
  /// May actually do the conversion, or return cached data.
  /// Callers should assume this method is expensive and call it as seldom as possible.
  /// This method is intended for decoding 1D barcodes and may choose to apply sharpening.
  /// For callers which only examine one row of pixels at a time, the same BitArray should be reused
  /// and passed in with each call for performance. However it is legal to keep more than one row
  /// at a time if needed
  BitArray getBlackRow(int y, BitArray? row);

  /// Get the 2D array of bits for the image (true means black).
  ///
  /// As above, assume this method is expensive and do not call it repeatedly.
  /// This method is intended for decoding 2D barcodes and may or may not apply sharpening.
  /// Therefore, a row from this matrix may not be identical to one
  /// fetched using getBlackRow(), so don't mix and match between them.
  /// throws [NotFoundException] if image can't be binarized to make a matrix
  BitMatrix get blackMatrix;

  /// Creates a [Binarizer] with the same type as this Binarizer implementation, but with pristine
  /// state.
  ///
  /// The [Binarizer] will operate on [source].
  /// This is needed because Binarizer implementations may be stateful, e.g. keeping a cache
  /// of 1 bit data. See Effective Java for why we can't use Java's clone() method.
  Binarizer createBinarizer(LuminanceSource source);

  int get width => _source.width;

  int get height => _source.height;
}
